==> declarative-linking-2.8-sources.jar: org/glassfish/jersey/examples/linking/model/ItemsModel.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2010-2014 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.jersey.examples.linking.model;

import java.util.ArrayList;
import java.util.List;

/**
 * Models a three entry list of items and provides a simple means of navigating
 * the list.
 *
 * @author Mark Hadley
 * @author Gerard Davison (gerard.davison at oracle.com)
 */
public class ItemsModel {

    private List<ItemModel> items;
    private static ItemsModel instance;

    public static synchronized ItemsModel getInstance() {
        if (instance==null) {
            instance = new ItemsModel();
        }
        return instance;
    }

    private ItemsModel() {
        items = new ArrayList<ItemModel>();
        items.add(new ItemModel("Item 0"));
        items.add(new ItemModel("Item 1"));
        items.add(new ItemModel("Item 2"));
        items.add(new ItemModel("Item 3"));
        items.add(new ItemModel("Item 4"));
    }

    public boolean hasNext(String currentId) {
        return getIndex(currentId) < items.size()-1;
    }

    public boolean hasPrev(String currentId) {
        return getIndex(currentId) > 0;
    }

    public ItemModel getItem(String id) {
        return items.get(getIndex(id));
    }

    public String getNextId(String id) {
        return Integer.toString(getIndex(id)+1);
    }

    public String getPrevId(String id) {
        return Integer.toString(getIndex(id)-1);
    }

    private int getIndex(String id) {
        return Integer.parseInt(id);
    }
}

==> declarative-linking-2.27-sources.jar: org/glassfish/jersey/examples/linking/model/ItemsModel.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2010-2017 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://oss.oracle.com/licenses/CDDL+GPL-1.1
 * or LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.jersey.examples.linking.model;

import java.util.ArrayList;
import java.util.List;

/**
 * Models a three entry list of items and provides a simple means of navigating
 * the list.
 *
 * @author Mark Hadley
 * @author Gerard Davison (gerard.davison at oracle.com)
 */
public class ItemsModel {

    private List<ItemModel> items;
    private static ItemsModel instance;

    public static synchronized ItemsModel getInstance() {
        if (instance == null) {
            instance = new ItemsModel();
        }
        return instance;
    }

    private ItemsModel() {
        items = new ArrayList<>();
        for (int i = 0; i < 100; i++) {
            items.add(new ItemModel("Item " + i));
        }
    }

    public boolean hasNext(String currentId) {
        return getIndex(currentId) < items.size() - 1;
    }

    public boolean hasPrev(String currentId) {
        return getIndex(currentId) > 0;
    }

    public ItemModel getItem(String id) {
        return items.get(getIndex(id));
    }

    public String getNextId(String id) {
        return Integer.toString(getIndex(id) + 1);
    }

    public String getPrevId(String id) {
        return Integer.toString(getIndex(id) - 1);
    }

    private int getIndex(String id) {
        return Integer.parseInt(id);
    }

    public int getSize() {
        return items.size();
    }
}
